Enum Event
#[non_exhaustive]pub enum Event<'a> {
Failed {
cause: WEnum<Cause>,
msg: String,
},
Ready {
identity: u32,
},
Ready2 {
identity_hi: u32,
identity_lo: u32,
},
}wayland and Linux only.Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Failed
graceful error on creating the image description
If creating a wp_image_description_v1 object fails for a reason that is not defined as a protocol error, this event is sent.
The requests that create image description objects define whether and when this can occur. Only such creation requests can trigger this event. This event cannot be triggered after the image description was successfully formed.
Once this event has been sent, the wp_image_description_v1 object will never become ready and it can only be destroyed.
Ready
the object is ready to be used (32-bit)
Starting from interface version 2, the ‘ready2’ event is sent instead of this event.
For the definition of this event, see the ‘ready2’ event. The difference to this event is as follows.
The id number is valid only as long as the protocol object is alive. If all protocol objects referring to the same image description record are destroyed, the id number may be recycled for a different image description record.
Ready2
the object is ready to be used
Once this event has been sent, the wp_image_description_v1 object is deemed “ready”. Ready objects can be used to send requests and can be used through other interfaces.
Every ready wp_image_description_v1 protocol object refers to an underlying image description record in the compositor. Multiple protocol objects may end up referring to the same record. Clients may identify these “copies” by comparing their id numbers: if the numbers from two protocol objects are identical, the protocol objects refer to the same image description record. Two different image description records cannot have the same id number simultaneously. The id number does not change during the lifetime of the image description record.
Image description id number is not a protocol object id. Zero is reserved as an invalid id number. It shall not be possible for a client to refer to an image description by its id number in protocol. The id numbers might not be portable between Wayland connections. A compositor shall not send an invalid id number.
Compositors must not recycle image description id numbers.
This identity allows clients to de-duplicate image description records and avoid get_information request if they already have the image description information.
Only available since version 2 of the interface
Implementations